# luketils

TODO add badges from PyPi and all the fun stuff

`luketils` is a Python utility package aimed at machine learning practitioners.
The goal of the package is to provide useful utilities in a coherently designed and
powerful API.